# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["FormattedGetParams"]


class FormattedGetParams(TypedDict, total=False):
    format: str
    """Provider format"""

    user_id: str
    """User ID"""
